#! /bin/sh
# vim:sts=4 sw=4 ts=4 et ai foldmethod=marker
#   Uninstallation script for the backup Agent Oracle plugin on Unix

message() #{{{
{
    if [ ${quiet} -eq 0 ]; then
        [ ${#} -gt 0 ] && echo "${@}" | tee -a ${logfile} || cat - | tee -a ${logfile}
    else
        [ ${#} -gt 0 ] && echo "${@}" >> ${logfile} || cat - >> ${logfile}
    fi
} #}}}

checkExists() #{{{
{
    found=0

    # check to see that the program exists in current directory
    for sofile in ${pluginSO}; do #{{{
        [ -f "${currentDir}/${sofile}" ] && found=1
    done #}}}

    if [ ${found} -eq 0 ]; then #{{{
        message <<EOS
`basename ${0}` could not find the Oracle plug-in.
Switch to the backup Agent directory and run `basename ${0}` again.
EOS
        exit 3
    fi #}}}
} #}}}

checkUninstallOK() #{{{
{
    if [ ${uninstallOK} -eq 0 ]; then #{{{
        asked=0
        printf "Do you really wish to proceed with the uninstall of the plugin? (y/[N]) "
        read ask

        while [ ${asked} -eq 0 ]; do #{{{
            case ${ask} in #{{{
                n|N)    uninstallOK=0
                        asked=1
                        ;;
                y|Y)    uninstallOK=1
                        asked=1
                        ;;
                *)      if [ "${ask}" = "" ]; then
                            uninstallOK=0
                            asked=1
                        else
                            printf "Unknown choice. Try again. (y/[N]) "
                            read ask
                        fi
                        ;;
            esac #}}}
        done #}}}

        if [ ${uninstallOK} -eq 0 ]; then #{{{
            message "Aborting uninstall."
            exit 4
        fi #}}}
    fi #}}}
} #}}}

initialize() #{{{
{
    quiet=0

    uninstallTime=`date +%y%m%d%H%M%S`
    currentDir=`pwd`

    logfile="/tmp/Agent-Oracle-Plugin-Uninstall-${uninstallTime}.log"

    uninstallOK=0
    pluginSO="oracle8i.so oracle.so"
    libfiles="libclntsh.so.11.1 libnnz11.so libociei.so libociicus.so"

    hasGrepW=1
    echo x | grep -w x 2>&1 > /dev/null
    if [ ${?} -gt 1 ]; then
        hasGrepW=0
    fi

    progVVAgent=VVAgent
    progVV=VV
} #}}}

initialize

message <<EOS


           *** Uninstalling Agent Oracle Plugin ***


EOS

checkExists
checkUninstallOK "${progVVAgent}"

message <<EOS

Uninstalling Agent Oracle plugin.

EOS

for sofile in ${pluginSO}; do
  rm -f "${currentDir}/${sofile}"
done

# remove the libs
for libfile in ${libfiles}; do
  rm -f "${currentDir}/${libfile}"
done

rm -f "${currentDir}/oratool"

message <<EOS

Unregistering the Agent Oracle plugin.

EOS
"${currentDir}/RegPlugins" -U ORACLE "${currentDir}" "${currentDir}/tmp" Oracle_Plugin.XLOG

message <<EOS

Oracle plugin successfully uninstalled.
Removing ${0}.

EOS

rm -f ${0}

rm -f "${currentDir}/.name"

exit 0
